summaryrefslogtreecommitdiff
path: root/gdb/m68klinux-nat.c
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2002-02-24 22:56:08 +0000
committerAndrew Cagney <cagney@redhat.com>2002-02-24 22:56:08 +0000
commitd81e3805c384665ba1c522fd5b72bc2d2dfc6efe (patch)
treeac2b6b56f7877d3e7cef7ced142b9a737cfa32d1 /gdb/m68klinux-nat.c
parent69f098507c1dc47662190c89cb49a94544d2202a (diff)
downloadgdb-d81e3805c384665ba1c522fd5b72bc2d2dfc6efe.tar.gz
s/Linux/.../
Fix PR gdb/378.
Diffstat (limited to 'gdb/m68klinux-nat.c')
-rw-r--r--gdb/m68klinux-nat.c15
1 files changed, 9 insertions, 6 deletions
diff --git a/gdb/m68klinux-nat.c b/gdb/m68klinux-nat.c
index 75427e3d942..ffb55326274 100644
--- a/gdb/m68klinux-nat.c
+++ b/gdb/m68klinux-nat.c
@@ -1,5 +1,7 @@
-/* Motorola m68k native support for Linux
- Copyright 1996, 1998, 2000, 2001 Free Software Foundation, Inc.
+/* Motorola m68k native support for GNU/Linux.
+
+ Copyright 1996, 1998, 2000, 2001, 2002 Free Software Foundation,
+ Inc.
This file is part of GDB.
@@ -445,7 +447,7 @@ fetch_inferior_registers (int regno)
return;
}
/* Linux LWP ID's are process ID's. */
if ((tid = TIDGET (inferior_ptid)) == 0)
tid = PIDGET (inferior_ptid); /* Not a threaded program. */
@@ -500,7 +502,7 @@ store_inferior_registers (int regno)
return;
}
/* Linux LWP ID's are process ID's. */
if ((tid = TIDGET (inferior_ptid)) == 0)
tid = PIDGET (inferior_ptid); /* Not a threaded program. */
@@ -546,7 +548,7 @@ store_inferior_registers (int regno)
0 --- the general-purpose register set, in elf_gregset_t format
2 --- the floating-point register set, in elf_fpregset_t format
- REG_ADDR isn't used on Linux. */
+ REG_ADDR isn't used on GNU/Linux. */
static void
fetch_core_registers (char *core_reg_sect, unsigned core_reg_size,
@@ -627,7 +629,8 @@ in_sigtramp (CORE_ADDR pc)
}
-/* Register that we are able to handle Linux ELF core file formats. */
+/* Register that we are able to handle GNU/Linux ELF core file
+ formats. */
static struct core_fns linux_elf_core_fns =
{
@@ -445,7 +447,7 @@ fetch_inferior_registers (int regno)
return;
}
- /* Linux LWP ID's are process ID's. */
+ /* GNU/Linux LWP ID's are process ID's. */
if ((tid = TIDGET (inferior_ptid)) == 0)
tid = PIDGET (inferior_ptid); /* Not a threaded program. */
@@ -500,7 +502,7 @@ store_inferior_registers (int regno)
return;
}
- /* Linux LWP ID's are process ID's. */
+ /* GNU/Linux LWP ID's are process ID's. */
if ((tid = TIDGET (inferior_ptid)) == 0)
tid = PIDGET (inferior_ptid); /* Not a threaded program. */